package fr.enssat.BoulderDash.models;

import fr.enssat.BoulderDash.helpers.AudioLoadHelper;
import fr.enssat.BoulderDash.helpers.LevelLoadHelper;


public class LevelModelFactory {
    public static LevelModel createLevelModel(String levelName, AudioLoadHelper audioLoadHelper, String mode) {
        LevelLoadHelper levelLoadHelper = new LevelLoadHelper(levelName);
        CursorModel cursorModel = new CursorModel();
        GameInformationModel gameInformationModel = new GameInformationModel(levelLoadHelper.getDiamondsToCatch());

        int sizeWidth = levelLoadHelper.getWidthSizeValue();
        int sizeHeight = levelLoadHelper.getHeightSizeValue();
        DisplayableElementModel[][] groundGrid = levelLoadHelper.getGroundGrid();
        createLimits(groundGrid, sizeWidth, sizeHeight);

        int rockfordPositionX = 0;
        int rockfordPositionY = 0;
        RockfordModel rockford = null;
        if(mode.equals("game")) {
            // initRockford
            rockfordPositionX = levelLoadHelper.getRockfordPositionX();
            rockfordPositionY = levelLoadHelper.getRockfordPositionY();
            rockford = levelLoadHelper.getRockfordInstance();
        }

        LevelModel levelModel = new LevelModel(audioLoadHelper, mode, true, cursorModel, gameInformationModel, groundGrid, sizeWidth, sizeHeight,
                rockfordPositionX, rockfordPositionY, rockford);

        if(mode.equals("game")) {
            // initThreadAnimator
            Thread spriteAnimator = new Thread(levelModel);
            spriteAnimator.start();
        }

        return levelModel;
    }

    public static LevelModel createLevelModel(String levelName, AudioLoadHelper audioLoadHelper) {
        return createLevelModel(levelName, audioLoadHelper, "game");
    }

    public static LevelModel createLevelModel(AudioLoadHelper audioLoadHelper) {
        CursorModel cursorModel = new CursorModel();

        int sizeWidth = 25 + 2;
        int sizeHeight = 25 + 2;
        DisplayableElementModel[][] groundGrid = new DisplayableElementModel[sizeWidth][sizeHeight];
        for (int x = 0; x < sizeWidth; x++) {
            for (int y = 0; y < sizeHeight; y++) {
                groundGrid[x][y] = new DirtModel();
            }
        }

        createLimits(groundGrid, sizeWidth, sizeHeight);


        return new LevelModel(audioLoadHelper, "editor", false, cursorModel, null, groundGrid, sizeWidth, sizeHeight,
                0, 0, null);
    }


    private static void createLimits(DisplayableElementModel[][] groundGrid,
                                     int sizeWidth,
                                     int sizeHeight) {
        int maxWidth = sizeWidth - 1;
        int maxHeight = sizeHeight - 1;

        for (int x = 0; x < sizeWidth; x++) {
            groundGrid[x][0] = new SteelWallModel();
            groundGrid[x][maxHeight] = new SteelWallModel();
        }
        for (int y = 0; y < sizeHeight; y++) {
            groundGrid[0][y] = new SteelWallModel();
            groundGrid[maxWidth][y] = new SteelWallModel();
        }
    }
}
