package dicegame.logic;

import java.util.Random;

public class Logic implements DiceInteraction {
   public static final int DICE_NUMBER = 6;
   public static final int DEFAULT_PLAYER_NUMBER = 2;
   public static final int DEFAULT_ROUNDS = 10;
   private static final int DIE_UNFIXED = 0;
   private static final int DIE_TEMP_FIXED = 1;
   private static final int DIE_FIXED = 2;
   private boolean gameIsRunning;
   private boolean playerCanThrowDice;
   private int currentPlayer;
   private int roundNumber;
   private int roundPoints;
   private int maxRounds = DEFAULT_ROUNDS;
   private int[] points = new int[2];
   private String[] names = new String[2];
   private int[] dicePips = new int[6];
   private int[] diceFixed = new int[6];
   private Random random;

   public Logic(Random random) {
      this.random = random;
   }

   public void startGame() {
      this.resetGame();
      this.gameIsRunning = true;
      this.playerCanThrowDice = true;
      this.roundNumber = 1;
      this.currentPlayer = 0;
   }

   public String rollDice() {
      if (!this.gameIsRunning) {
         return "Das Spiel läuft aktuell nicht!";
      } else {
         if (this.isAllDiceFixed()) {
            this.resetDice();
         }

         for(int i = 0; i < DICE_NUMBER; ++i) {
            if (this.diceFixed[i] == DIE_TEMP_FIXED) {
               this.diceFixed[i] = DIE_FIXED;
            } else if (this.diceFixed[i] == DIE_UNFIXED) {
               this.dicePips[i] = this.random.nextInt(6) + 1;
            }
         }

         if (this.isScoringPipsAvailable()) {
            this.playerCanThrowDice = true;
         } else {
            this.playerCanThrowDice = false;
            this.roundPoints = 0;
         }

         return null;
      }
   }

   public boolean isScoringPipsAvailable() {
      for(int i = 0; i < DICE_NUMBER; ++i) {
         if (this.diceFixed[i] != DIE_FIXED && (this.dicePips[i] == 5 || this.dicePips[i] == 1)) {
            return true;
         }
      }

      return false;
   }

   private boolean isAllDiceFixed() {
      for(int i = 0; i < DICE_NUMBER; ++i) {
         if (this.diceFixed[i] == DIE_UNFIXED) {
            return false;
         }
      }

      return true;
   }

   public String checkIfGameCanStart() {
      if (this.gameIsRunning) {
         return "Das Spiel läuft bereits!";
      } else {
         for(int i = 0; i < DEFAULT_PLAYER_NUMBER; ++i) {
            if (this.names[i] == null || this.names[i].trim().length() < 2) {
               return "Spieler " + (i + 1) + " hat noch keinen Namen!";
            }
         }

         return null;
      }
   }

   public void resetGame() {
      this.roundNumber = 0;
      this.roundPoints = 0;
      this.resetDice();
      this.resetPoints();
   }

   public void finishRound() {
      this.resetDice();
      int[] var10000 = this.points;
      int var10001 = this.currentPlayer;
      var10000[var10001] += this.roundPoints;
      this.roundPoints = 0;
      this.currentPlayer = ++this.currentPlayer % DEFAULT_PLAYER_NUMBER;
      if (this.currentPlayer == 0) {
         if (this.roundNumber == this.maxRounds) {
            this.gameIsRunning = false;
         } else {
            ++this.roundNumber;
         }
      }

   }

   private void resetDice() {
      for(int i = 0; i < DICE_NUMBER; ++i) {
         this.diceFixed[i] = DIE_UNFIXED;
      }

   }

   private void resetPoints() {
      for(int i = 0; i < DEFAULT_PLAYER_NUMBER; ++i) {
         this.points[i] = 0;
      }

   }

   public int getRoundNumber() {
      return this.roundNumber;
   }

   public int getRoundPoints() {
      return this.roundPoints;
   }

   public boolean isDieFixed(int dieIndex) {
      return this.diceFixed[dieIndex] != DIE_UNFIXED;
   }

   public boolean isAtLeastOneDieFixedInCurrentThrow() {
      for(int i = 0; i < DICE_NUMBER; ++i) {
         if (this.diceFixed[i] == DIE_TEMP_FIXED) {
            return true;
         }
      }

      return false;
   }

   private int countTempFixedByPips(int pips) {
      int count = 0;

      for(int i = 0; i < DICE_NUMBER; ++i) {
         if (this.diceFixed[i] == DIE_TEMP_FIXED && this.dicePips[i] == pips) {
            ++count;
         }
      }

      return count;
   }

   public int getDiePips(int dieIndex) {
      return this.dicePips[dieIndex];
   }

   public int getMaxRounds() {
      return this.maxRounds;
   }

   public String setMaxRounds(int maxRounds) {
      if (this.gameIsRunning) {
         return "Rundenzahl kann nicht während eines Spiels verändert werden!";
      } else {
         this.maxRounds = maxRounds;
         return null;
      }
   }

   public int getPoints(int playerIndex) {
      return this.points[playerIndex];
   }

   public String getName(int playerIndex) {
      return this.names[playerIndex];
   }

   public String setName(int playerIndex, String name) {
      if (this.gameIsRunning) {
         return "Ein Spielername kann nicht während eines Spiels verändert werden!";
      } else {
         this.names[playerIndex] = name;
         return null;
      }
   }

   public boolean isPlayerCanThrowDice() {
      return this.playerCanThrowDice;
   }

   public boolean isGameIsRunning() {
      return this.gameIsRunning;
   }

   public int getCurrentPlayer() {
      return this.currentPlayer;
   }

   @Override
   public int changeDiceState(int diceIndex) throws SelectionException {
      if (this.diceFixed[diceIndex] == DIE_UNFIXED) {
         setDieFixed(diceIndex);
      } else {
         setDieUnfixed(diceIndex);
      }
      return roundPoints;
   }

   private void setDieFixed(int dieIndex) throws SelectionException {
      int c;
      if (this.dicePips[dieIndex] == 1) {
         c = this.countTempFixedByPips(1);
         if (c != 2 && c != 5) {
            this.roundPoints += 100;
         } else {
            this.roundPoints -= 200;
            this.roundPoints += 1000;
         }

         this.diceFixed[dieIndex] = DIE_TEMP_FIXED;
      } else if (this.dicePips[dieIndex] == 5) {
         c = this.countTempFixedByPips(5);
         if (c != 2 && c != 5) {
            this.roundPoints += 50;
         } else {
            this.roundPoints -= 100;
            this.roundPoints += 500;
         }

         this.diceFixed[dieIndex] = DIE_TEMP_FIXED;
      } else {
         throw new SelectionException("Es können nur 1'en und 5'en fixiert werden!");
      }
   }

   private void setDieUnfixed(int dieIndex) throws SelectionException {
      int c;
      if (this.dicePips[dieIndex] == 1) {
         c = this.countTempFixedByPips(1);
         if (c != 3 && c != 6) {
            this.roundPoints -= 100;
         } else {
            this.roundPoints -= 1000;
            this.roundPoints += 200;
         }

         this.diceFixed[dieIndex] = DIE_UNFIXED;
      } else if (this.dicePips[dieIndex] == 5) {
         c = this.countTempFixedByPips(5);
         if (c != 3 && c != 6) {
            this.roundPoints -= 50;
         } else {
            this.roundPoints -= 500;
            this.roundPoints += 100;
         }

         this.diceFixed[dieIndex] = DIE_UNFIXED;
      }
   }
}
