package client;

import model.Article;
import model.Image;
import model.NewsCollection;

public class Client {
	
	public static void main(String[] args) {
		NewsCollection masterCollection = new NewsCollection("Daily news");
		masterCollection.addCollection(new NewsCollection("Sports")
				.addArticle(new Article("Harder, Better, Faster, Stronger. Doping controls loosened","ups"))
				.addImage(new Image("Athletic cat contest", 800, 600, "zdf")))
		.addCollection(new NewsCollection("Local news")
				.addArticle(new Article("Missing Cat missed.", "mfg"))
				.addArticle(new Article("Corrupted local politician selling cats.", "ard"))
				.addImage(new Image("Missing cat", 1280, 720, "anonymous")));
		
		System.out.println("\n===List===\n");
		System.out.print(getOverviewInformation(masterCollection));
		System.out.println("\n===Contents===\n");
		System.out.print(getDetailedInformation(masterCollection));
	}
	
	/**
	 * Gets overview information about all directly or transitively
	 * referenced items in the given collection.
	 */	
	public static String getOverviewInformation(NewsCollection rootCollection) {
		StringBuilder builder = new StringBuilder();
		builder.append("###" + rootCollection.getTopic() + "###");
		builder.append("\n");
		for (Article article : rootCollection.getArticles()) {
			builder.append("Article: " + article.getTitle() + ", Author: "
					+ article.getAuthor());
			builder.append("\n");
		}
		for (Image image : rootCollection.getImages()) {
			builder.append("Image: " + image.getTitle()
					+ ", Resolution: " + image.getWidth() 
					+ "x" + image.getHeight() 
					+ ", Author: " + image.getAuthor());
			builder.append("\n");
		}
		for (NewsCollection collection : rootCollection.getCollections()) {
			builder.append(getOverviewInformation(collection));
			builder.append("\n");
		}
		return builder.toString();
	}
	
	/**
	 * Gets the contents of all directly or transitively referenced items in
	 * the given collection.
	 */	
	public static String getDetailedInformation(NewsCollection rootCollection) {
		StringBuilder builder = new StringBuilder();
		builder.append("###" + rootCollection.getTopic() + "###");
		builder.append("\n");
		for (Article article : rootCollection.getArticles()) {
			builder.append("###" + article.getTitle() + "###");
			builder.append("\n");
			builder.append(article.getContent());
			builder.append("\n\n");
		}
		for (Image image : rootCollection.getImages()) {
			builder.append("###" + image.getTitle() + "###");
			builder.append("\n");
			builder.append(image.renderToString());
			builder.append("\n\n");
		}
		for (NewsCollection collection : rootCollection.getCollections()) {
			builder.append(getDetailedInformation(collection));
		}
		return builder.toString();
	}	
}
