package model;

import java.util.LinkedList;
import java.util.List;

public class NewsCollection extends NewsItem {
	
	private List<NewsItem> newsItems = new LinkedList<NewsItem>();
			
	public NewsCollection(String topic) {
		this.title = topic;
	}
	
	/**
	 * Get the list of items stored in this collection.
	 * @return items stored in this collection
	 */
	public List<NewsItem> getNewsItems() {
		return newsItems;
	}
	
	/**
	 * Store another item to this collection.
	 * @param item
	 * @return this collection (enables method chaining)
	 */
	public NewsCollection addItem(NewsItem item) {
		newsItems.add(item);
		return this;
	}
	
	/**
	 * Print a list showing information about all directly or transitively
	 * referenced items in the given collection.
	 */
	public String getOverviewInformation() {
		StringBuilder builder = new StringBuilder();
		builder.append("###" + this.getTitle() + "###");
		builder.append("\n");
		for (NewsItem item : this.getNewsItems()) {
			builder.append(item.getOverviewInformation());
			builder.append("\n");
		}
		return builder.toString();
	}

	@Override
	public String getDetailedInformation() {
		StringBuilder builder = new StringBuilder();
		builder.append("###" + this.getTitle() + "###");
		builder.append("\n");
		for (NewsItem item : this.getNewsItems()) {
			builder.append(item.getDetailedInformation());
			builder.append("\n");
		}
		return builder.toString();
	}	
}
